@@ -1079,6 +1079,9 @@ void handle_command_sequence(char input_char, char *output_char, bool *forward)
                     case TIMESTAMP_ISO8601:
                         tio_printf("Switched timestamp mode to iso8601");
                         break;
+                    case TIMESTAMP_EPOCH:
+                        tio_printf("Switched timestamp mode to epoch");
+                        break;
                     case TIMESTAMP_END:
                         option.timestamp = TIMESTAMP_NONE;
                         tio_printf("Switched timestamp mode off");
@@ -2669,7 +2672,6 @@ int tty_connect(void)
                                         // Write current line to tty device
                                         char *rl_line = readline_get();
                                         tty_write(device_fd, rl_line, strlen(rl_line));
-                                        tty_sync(device_fd);
                                     }
                                     else
                                     {
